@@ -2,44 +2,41 @@
 library(testthat)
 library(TreatmentPatterns)
 library(dplyr)
-library(stringr)
 
-test_that("computePathways DatabaseConnector", {
-  skip("Eunomia [2.0.0] bug")
-  skip_on_cran()
-  skip_if_not(ableToRun()$CG)
-  globals <- generateCohortTableCG()
-
-  expect_message(
-    expect_message(
-      expect_message(
-        computePathways(
-          cohorts = globals$cohorts,
-          cohortTableName = globals$cohortTableName,
-          connectionDetails = globals$connectionDetails,
-          cdmSchema = "main",
-          resultSchema = "main"
-        ),
-        "After maxPathLength: 553"
-      ),
-      "After combinationWindow: 554"
-    ),
-    "Original number of rows: 8366"
-  )
-})
+# test_that("computePathways DatabaseConnector", {
+#   skip("Eunomia [2.0.0] bug")
+#   skip_on_cran()
+#   skip_if_not(ableToRun()$CG)
+# 
+#   expect_message(
+#     expect_message(
+#       expect_message(
+#         computePathways(
+#           cohorts = .CG$cohorts,
+#           cohortTableName = .CG$cohortTableName,
+#           connectionDetails = .CG$connectionDetails,
+#           cdmSchema = "main",
+#           resultSchema = "main"
+#         ),
+#         "After maxPathLength: 554"
+#       ),
+#       "After combinationWindow: 554"
+#     ),
+#     "Original number of rows: 8366"
+#   )
+# })
 
 test_that("computePathways CDMConnector", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  globals <- generateCohortTableCDMC()
 
   expect_message(
     expect_message(
       expect_message(
         computePathways(
-          cohorts = globals$cohorts,
-          cdm = globals$cdm,
-          globals$cohortTableName
+          cohorts = .CM$cohorts,
+          cdm = .CM$cdm,
+          .CM$cohortTableName
         ),
         ">> Starting on"
       ),
@@ -47,45 +44,41 @@ test_that("computePathways CDMConnector", {
     ),
     "-- treatment construction done"
   )
-
-  DBI::dbDisconnect(globals$con, shutdown = TRUE)
 })
 
-test_that("nrow exitCohorts > 0", {
-  skip("Eunomia [2.0.0] bug")
-  skip_on_cran()
-  skip_if_not(ableToRun()$CG)
-  globals <- generateCohortTableCG()
-
-  cohorts <- globals$cohorts %>%
-    mutate(type = case_when(
-      .data$cohortName == "Acetaminophen" ~ "exit",
-      .default = .data$type
-    ))
-
-  expect_message(
-    computePathways(
-      connectionDetails = globals$connectionDetails,
-      cdmSchema = globals$cdmSchema,
-      resultSchema = globals$resultSchema,
-      cohorts = cohorts,
-      cohortTableName = globals$cohortTableName
-    ),
-    "Records: 2117"
-  )
-})
+# test_that("nrow exitCohorts > 0", {
+#   skip("Eunomia [2.0.0] bug")
+#   skip_on_cran()
+#   skip_if_not(ableToRun()$CG)
+# 
+#   cohorts <- .CG$cohorts %>%
+#     mutate(type = case_when(
+#       .data$cohortName == "Acetaminophen" ~ "exit",
+#       .default = .data$type
+#     ))
+# 
+#   expect_message(
+#     computePathways(
+#       connectionDetails = .CG$connectionDetails,
+#       cdmSchema = .CG$cdmSchema,
+#       resultSchema = .CG$resultSchema,
+#       cohorts = cohorts,
+#       cohortTableName = .CG$cohortTableName
+#     ),
+#     "Records: 2117"
+#   )
+# })
 
 # Parameter sweep ----
 test_that("windowStart", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  globals <- generateCohortTableCDMC()
 
   expect_error(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       windowStart = "0"
     ),
     "Must be of type.+'integerish'"
@@ -93,9 +86,9 @@ test_that("windowStart", {
 
   expect_error(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       windowStart = Inf
     ),
     "Must be of type.+'integerish'"
@@ -103,9 +96,9 @@ test_that("windowStart", {
 
   expect_message(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       windowStart = 0
     ),
     "Records: 8366"
@@ -113,9 +106,9 @@ test_that("windowStart", {
 
   expect_message(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       windowStart = -30
     ),
     "Records: 8366"
@@ -123,9 +116,9 @@ test_that("windowStart", {
 
   expect_message(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       windowStart = 30
     ),
     "Records: 6267"
@@ -135,13 +128,12 @@ test_that("windowStart", {
 test_that("minEraDuration", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  globals <- generateCohortTableCDMC()
 
   expect_error(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       minEraDuration = "0"
     ),
     "Must be of type.+'numeric'"
@@ -151,19 +143,18 @@ test_that("minEraDuration", {
 test_that("splitEventCohorts", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  globals <- generateCohortTableCDMC()
 
   andromeda_empty <- computePathways(
-    cohorts = globals$cohorts,
-    cohortTableName = globals$cohortTableName,
-    cdm = globals$cdm,
+    cohorts = .CM$cohorts,
+    cohortTableName = .CM$cohortTableName,
+    cdm = .CM$cdm,
     splitEventCohorts = NULL
   )
 
   andromeda_Clavulanate <- computePathways(
-    cohorts = globals$cohorts,
-    cohortTableName = globals$cohortTableName,
-    cdm = globals$cdm,
+    cohorts = .CM$cohorts,
+    cohortTableName = .CM$cohortTableName,
+    cdm = .CM$cdm,
     splitEventCohorts = 4,
     splitTime = 30
   )
@@ -175,9 +166,9 @@ test_that("splitEventCohorts", {
 
   expect_error(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       splitEventCohorts = "1"
     ),
     "Must be of type.+'integerish'"
@@ -190,13 +181,12 @@ test_that("splitEventCohorts", {
 test_that("splitTime", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  globals <- generateCohortTableCDMC()
 
   expect_error(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       splitTime = "1"
     ),
     "Must be of type.+'integerish'"
@@ -206,27 +196,26 @@ test_that("splitTime", {
 test_that("eraCollapseSize", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  globals <- generateCohortTableCDMC()
 
   andromeda_0 <- computePathways(
-    cohorts = globals$cohorts,
-    cohortTableName = globals$cohortTableName,
-    cdm = globals$cdm,
+    cohorts = .CM$cohorts,
+    cohortTableName = .CM$cohortTableName,
+    cdm = .CM$cdm,
     eraCollapseSize = 0
   )
 
   andromeda_10000 <- computePathways(
-    cohorts = globals$cohorts,
-    cohortTableName = globals$cohortTableName,
-    cdm = globals$cdm,
+    cohorts = .CM$cohorts,
+    cohortTableName = .CM$cohortTableName,
+    cdm = .CM$cdm,
     eraCollapseSize = 10000
   )
 
   expect_error(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       eraCollapseSize = ""
     ),
     " Must be of type.+'numeric'"
@@ -239,14 +228,13 @@ test_that("eraCollapseSize", {
 test_that("combinationWindow", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  globals <- generateCohortTableCDMC()
 
   expect_error(
     suppressWarnings(
       computePathways(
-        cohorts = globals$cohorts,
-        cohortTableName = globals$cohortTableName,
-        cdm = globals$cdm,
+        cohorts = .CM$cohorts,
+        cohortTableName = .CM$cohortTableName,
+        cdm = .CM$cdm,
         combinationWindow = ""
       )
     ),
@@ -357,43 +345,40 @@ test_that("minPostCombinationDuration: 30", {
     dplyr::pull(.data$pathway)
 
   expect_identical(pathway, "A-A+B-B")
-
-  DBI::dbDisconnect(con)
 })
 
 test_that("filterTreatments", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  globals <- generateCohortTableCDMC()
 
   expect_error(
     computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm,
       filterTreatments = ""
     ),
     "Must be a subset of"
   )
 
   first <- computePathways(
-    cohorts = globals$cohorts,
-    cohortTableName = globals$cohortTableName,
-    cdm = globals$cdm,
+    cohorts = .CM$cohorts,
+    cohortTableName = .CM$cohortTableName,
+    cdm = .CM$cdm,
     filterTreatments = "First"
   )
 
   changes <- computePathways(
-    cohorts = globals$cohorts,
-    cohortTableName = globals$cohortTableName,
-    cdm = globals$cdm,
+    cohorts = .CM$cohorts,
+    cohortTableName = .CM$cohortTableName,
+    cdm = .CM$cdm,
     filterTreatments = "Changes"
   )
 
   all <- computePathways(
-    cohorts = globals$cohorts,
-    cohortTableName = globals$cohortTableName,
-    cdm = globals$cdm,
+    cohorts = .CM$cohorts,
+    cohortTableName = .CM$cohortTableName,
+    cdm = .CM$cdm,
     filterTreatments = "All"
   )
 
@@ -439,25 +424,31 @@ test_that("filterTreatments", {
     object = c("numeric", "integer")
   )
 
-  expect_identical(
-    "numeric",
-    class(firstTH$eventStartDate),
-    class(changesTH$eventStartDate),
-    class(allTH$eventStartDate)
+  expect_contains(
+    expected = c(
+      class(firstTH$eventStartDate),
+      class(changesTH$eventStartDate),
+      class(allTH$eventStartDate)
+    ),
+    object = c("numeric", "integer")
   )
 
-  expect_identical(
-    "numeric",
-    class(firstTH$eventEndDate),
-    class(changesTH$eventStartDate),
-    class(allTH$eventEndDate)
+  expect_contains(
+    expected = c(
+      class(firstTH$eventEndDate),
+      class(changesTH$eventStartDate),
+      class(allTH$eventEndDate)
+    ),
+    object = c("numeric", "integer")
   )
 
-  expect_identical(
-    "numeric",
-    class(firstTH$age),
-    class(changesTH$age),
-    class(allTH$age)
+  expect_contains(
+    expected = c(
+      class(firstTH$age),
+      class(changesTH$age),
+      class(allTH$age)
+    ),
+    object = c("numeric", "integer")
   )
 
   expect_identical(
@@ -467,18 +458,22 @@ test_that("filterTreatments", {
     class(allTH$sex)
   )
 
-  expect_identical(
-    "numeric",
-    class(firstTH$durationEra),
-    class(changesTH$durationEra),
-    class(allTH$durationEra)
+  expect_contains(
+    expected = c(
+      class(firstTH$durationEra),
+      class(changesTH$durationEra),
+      class(allTH$durationEra)
+    ),
+    object = c("numeric", "integer")
   )
 
-  expect_identical(
-    "numeric",
-    class(firstTH$sortOrder),
-    class(changesTH$sortOrder),
-    class(allTH$sortOrder)
+  expect_contains(
+    expected = c(
+      class(firstTH$sortOrder),
+      class(changesTH$sortOrder),
+      class(allTH$sortOrder)
+    ),
+    object = c("numeric", "integer")
   )
 
   expect_true(
@@ -556,8 +551,6 @@ test_that("FRFS combination", {
 
   expect_equal(nFRFS, 1)
   expect_equal(nLRFS, 0)
-
-  DBI::dbDisconnect(con)
 })
 
 test_that("LRFS combination", {
@@ -607,104 +600,88 @@ test_that("LRFS combination", {
 
   expect_equal(nFRFS, 0)
   expect_equal(nLRFS, 1)
-
-  DBI::dbDisconnect(con)
 })
 
 test_that("No target records", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
 
-  params <- suppressWarnings(generateCohortTableCDMC())
-
-  params$cohorts$cohortId[8] <- 9
+  .CM$cohorts$cohortId[8] <- 9
 
   expect_warning({
     outputEnv <- computePathways(
-      cohorts = params$cohorts,
-      cohortTableName = params$cohortTableName,
-      cdm = params$cdm
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm
     )
   })
 
   expect_true(nrow(outputEnv$treatmentHistory %>% collect()) == 0)
-
-  DBI::dbDisconnect(params$con, shutdown = TRUE)
 })
 
 test_that("Empty cohort table", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
 
-  params <- suppressWarnings(generateCohortTableCDMC())
-
-  params$cdm$cohort_table <- params$cdm$cohort_table %>%
+  .CM$cdm$cohort_table <- .CM$cdm$cohort_table %>%
     filter(.data$cohort_definition_id <= 0) %>%
     compute()
 
   expect_warning({
     outputEnv <- computePathways(
-      cohorts = params$cohorts,
-      cohortTableName = params$cohortTableName,
-      cdm = params$cdm
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm
     )
   })
 
   expect_true(nrow(outputEnv$treatmentHistory %>% collect()) == 0)
-
-  DBI::dbDisconnect(params$con, shutdown = TRUE)
 })
 
 test_that("No target defined", {
   skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
 
-  params <- suppressWarnings(generateCohortTableCDMC())
-
-  params$cohorts$type <- rep("event", 8)
+  .CM$cohorts$type <- rep("event", 8)
 
   expect_error({
     outputEnv <- computePathways(
-      cohorts = params$cohorts,
-      cohortTableName = params$cohortTableName,
-      cdm = params$cdm
+      cohorts = .CM$cohorts,
+      cohortTableName = .CM$cohortTableName,
+      cdm = .CM$cdm
     )
   })
-
-  DBI::dbDisconnect(params$con, shutdown = TRUE)
 })
 
-test_that("Attrition", {
-  skip_on_cran()
-  skip_on_os(os = "linux")
-  skip_if_not(ableToRun()$CDMC)
-  skip_if_not(ableToRun()$CG)
-
-  params <- suppressWarnings(generateCohortTableCDMC())
-  outputEnvCDMC <- computePathways(
-    cohorts = params$cohorts,
-    cohortTableName = params$cohortTableName,
-    cdm = params$cdm
-  )
-
-  params <- suppressWarnings(generateCohortTableCG())
-  outputEnvCG <- computePathways(
-    cohorts = params$cohorts,
-    cohortTableName = params$cohortTableName,
-    connectionDetails = params$connectionDetails,
-    cdmSchema = params$cdmSchema,
-    resultSchema = params$resultSchema
-  )
-
-  expect_identical(
-    outputEnvCDMC$attrition %>%
-      collect() %>%
-      select(-"time_stamp"),
-    outputEnvCG$attrition %>%
-      collect() %>%
-      select(-"time_stamp")
-  )
-
-  Andromeda::close(outputEnvCG)
-  Andromeda::close(outputEnvCDMC)
-})
+# test_that("Attrition", {
+#   skip_on_cran()
+#   skip_on_os(os = "linux")
+#   skip_if_not(ableToRun()$CDMC)
+#   skip_if_not(ableToRun()$CG)
+# 
+#   outputEnvCDMC <- computePathways(
+#     cohorts = .CM$cohorts,
+#     cohortTableName = .CM$cohortTableName,
+#     cdm = .CM$cdm
+#   )
+# 
+#   outputEnvCG <- computePathways(
+#     cohorts = .CM$cohorts,
+#     cohortTableName = .CM$cohortTableName,
+#     connectionDetails = .CM$connectionDetails,
+#     cdmSchema = .CM$cdmSchema,
+#     resultSchema = .CM$resultSchema
+#   )
+# 
+#   expect_identical(
+#     outputEnvCDMC$attrition %>%
+#       collect() %>%
+#       select(-"time_stamp"),
+#     outputEnvCG$attrition %>%
+#       collect() %>%
+#       select(-"time_stamp")
+#   )
+# 
+#   Andromeda::close(outputEnvCG)
+#   Andromeda::close(outputEnvCDMC)
+# })
