@@ -1,5 +1,7 @@
 test_that("ggSunburst", {
   skip_on_cran()
+  skip_if_not_installed("ggplot2")
+
   treatmentPathways <- data.frame(
     pathway = c("A", "C-B", "A-B-C", "B", "B+A", "B-A-C"),
     freq = c(100, 75, 25, 500, 350, 20),
@@ -17,11 +19,13 @@ test_that("ggSunburst", {
     )
 
   expect_true(all(unique(gg$data$frac) %in% unique(df$frac)))
-  expect_true(all(class(gg) %in% c("gg", "ggplot")))
+  expect_true(any(class(gg) %in% c("gg", "ggplot")))
 })
 
 test_that("ggSunburst: groupCombinations", {
   skip_on_cran()
+  skip_if_not_installed("ggplot2")
+
   treatmentPathways <- data.frame(
     pathway = c("A", "C-B", "A-B-C", "B", "B+A", "B-A-C"),
     freq = c(100, 75, 25, 500, 350, 20),
@@ -38,6 +42,8 @@ test_that("ggSunburst: groupCombinations", {
 
 test_that("ggSunburst: unit", {
   skip_on_cran()
+  skip_if_not_installed("ggplot2")
+
   treatmentPathways <- data.frame(
     pathway = c("A", "C-B", "A-B-C", "B", "B+A", "B-A-C"),
     freq = c(100, 75, 25, 500, 350, 20),
